@@ -5,11 +5,14 @@ from visits.utils import is_ignored
 
 class CounterMiddleware:
     def process_request(self, request):
-        Visit.objects.add_uri_visit(request, request.META["PATH_INFO"])
+        if settings.URI_WITH_GET_PARAMS:
+            Visit.objects.add_uri_visit(request, request.get_full_path())
+        else:
+            Visit.objects.add_uri_visit(request, request.path_info)
 
 class BotVisitorMiddleware:
     def process_request(self, request):
-        user_agent = request.META["HTTP_USER_AGENT"] or None
-        if user_agent in settings.IGNORE_USER_AGENTS:
+        user_agent = request.META.get("HTTP_USER_AGENT", None)
+        if user_agent in settings.BOTS_USER_AGENTS:
             request.META.setdefault("IS_BOT", True)
         request.META.setdefault("IS_BOT", False)
