@@ -3,9 +3,10 @@ from django.conf import settings
 # The minimum time between two counted visits (in minutes)
 MIN_TIME_BETWEEN_VISITS = getattr(settings, 'MIN_TIME_BETWEEN_VISITS', 24 * 60)
 IGNORE_URLS = getattr(settings, 'IGNORE_URLS', {})
-IGNORE_USER_AGENTS = getattr(
+IGNORE_USER_AGENTS = getattr(settings, 'IGNORE_USER_AGENTS', [])
+BOTS_USER_AGENTS = getattr(
         settings,
-        'IGNORE_USER_AGENTS',
+        'BOTS_USER_AGENTS',
         [
                 "Teoma", "alexa", "froogle", "Gigabot", "inktomi", "looksmart", "URL_Spider_SQL", "Firefly",
                 "NationalDirectory", "Ask Jeeves", "TECNOSEEK", "InfoSeek", "WebFindBot", "girafabot", "crawler",
@@ -17,3 +18,4 @@ IGNORE_USER_AGENTS = getattr(
 )
 
 REQUEST_FIELDS_FOR_HASH = getattr(settings, 'REQUEST_FIELDS_FOR_HASH', ['REMOTE_ADDR', 'HTTP_USER_AGENT'])
+URI_WITH_GET_PARAMS = getattr(settings, 'URI_WITH_GET_PARAMS', False)
